package com.nisum.spark.publisher;


import org.apache.spark.sql.*;

import org.apache.spark.storage.StorageLevel;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;
import java.util.Map;
import static com.nisum.spark.util.Constants.*;


public class Publisher {
    static Logger log =  LoggerFactory.getLogger(Publisher.class);
    public static void main(String[] args) {
        SparkSession sparkSession = SparkSession
                .builder().master("local[*]").appName("Spark Streaming Example").getOrCreate();
        log.debug("spark session is created");
        Dataset<Row> dataset = sparkSession.read().
                format("csv").option("header", true).
                load("src/main/resources/productData.csv");
        dataset.show();
        publishCsvRecordsToKafkaTopic(dataset);
    }
    private static void publishCsvRecordsToKafkaTopic(Dataset<Row> rowDataset) {
        if (null != rowDataset) {
            log.debug("reading from CSV file");
            Dataset<Row> KafkaPublishJson = rowDataset
                    .withColumn("value", functions.to_json(functions.struct(functions.col("productId"),
                            functions.col("productName"), functions.col("productPrice"),
                            functions.col("deliveryStatus"), functions.col("date"))))
                    .alias("value").select("value")
                    .persist(StorageLevel.MEMORY_AND_DISK());
            log.debug("publishing to kafka");
            KafkaPublishJson
                    .write().format("kafka").options(KafkaCsvConfig()).save();
        }
    }

    private static Map<String, String> KafkaCsvConfig() {
        Map<String, String> kafkaConfigMap = new HashMap<>();
        kafkaConfigMap.put("kafka.bootstrap.servers", HOST);
        kafkaConfigMap.put("topic", TOPIC);
        return kafkaConfigMap;
    }
}
